@@ -125,7 +125,7 @@ class Shell:
         if message is None:
             self.error("Exiting due to error")
         else:
-            self.error("Exiting due to error: {}".format(message))
+            self.error(f"Exiting due to error: {message}")
         sys.exit(1)
 
     def error(self, message):
@@ -145,13 +145,13 @@ class Shell:
             colorize = getattr(colored, color)
             print(colorize(message))
 
-    def prompt(self, message, *, default=None, force_arg=None):
+    def prompt(self, message, *, default=None, force_arg=None, force_arg_value=True):
         """
         A Yes/No prompt that accepts optional defaults
         Returns True for Yes and False for No
         """
         if force_arg is not None and self.argument_exists(force_arg):
-            return True
+            return force_arg_value
         if default is None:
             choicebox = "[y/n]"
         else:
@@ -257,9 +257,7 @@ class Shell:
         Run the grep command and return the result
         """
         location = self.path(location)
-        return self.run_command(
-            "grep {} {}".format(search_term, location), suppress_message=True
-        )
+        return self.run_command(f"grep {search_term} {location}", suppress_message=True)
 
     @staticmethod
     def date():
@@ -385,7 +383,7 @@ class Shell:
         """
         if not self.is_root():
             print("Installer must be run as root.")
-            print("Try 'sudo python3 {}'".format(self.script()))
+            print(f"Try 'sudo python3 {self.script()}'")
             sys.exit(1)
 
     def write_text_file(self, path, content, append=True):
@@ -493,7 +491,7 @@ class Shell:
         """Return a string containing the raspbian version"""
         if self.get_os() != "Raspbian":
             return None
-        raspbian_releases = ("buster", "stretch", "jessie", "wheezy")
+        raspbian_releases = ("bullseye", "buster", "stretch", "jessie", "wheezy")
         if os.path.exists("/etc/os-release"):
             with open("/etc/os-release", encoding="utf-8") as f:
                 release_file = f.read()
@@ -504,9 +502,9 @@ class Shell:
                         return raspbian
         return None
 
-    def prompt_reboot(self):
+    def prompt_reboot(self, default="y", **kwargs):
         """Prompt the user for a reboot"""
-        if not self.prompt("REBOOT NOW?", default="y"):
+        if not self.prompt("REBOOT NOW?", default=default, **kwargs):
             print("Exiting without reboot.")
         else:
             print("Reboot started...")
@@ -516,7 +514,7 @@ class Shell:
 
     def check_kernel_update_reboot_required(self):
         """Checks if the pi needs to be rebooted since the last kernel update"""
-        if not self.exists("/lib/modules/{}".format(self.release())):
+        if not self.exists(f"/lib/modules/{self.release()}"):
             self.error(
                 "OS has not been rebooted since last kernel update. "
                 "Please reboot and re-run the script."
